"""Top-level package for OCRfixr."""

__author__ = """Jack McMahon"""
__email__ = 'OCRfixr@mcmahon.work'
__version__ = '0.1.0'

from .spellcheck import spellcheck
from .unsplit import unsplit
